@@ -86,26 +86,27 @@ __tests__ = (
     "#options" : {"max-posts": 100, "endpoint": "posts"},
     "#count"   : range(200, 400),
 
-    "added"      : {str, None},
     "archives"   : [],
     "attachments": list,
-    "captions"   : None,
-    "content"    : str,
     "count"      : int,
     "num"        : int,
-    "date"       : "type:datetime",
-    "edited"     : {str, None},
-    "embed"      : dict,
     "id"         : str,
-    "poll"       : None,
+    "date"       : "type:datetime",
     "published"  : str,
     "service"    : "patreon",
-    "shared_file": False,
     "subcategory": "patreon",
-    "tags"       : {str, None},
     "title"      : str,
     "user"       : "881792",
     "username"   : "diives",
+
+    "!added"      : {str, None},
+    "!captions"   : None,
+    "!content"    : str,
+    "!edited"     : {str, None},
+    "!embed"      : dict,
+    "!poll"       : None,
+    "!shared_file": False,
+    "!tags"       : {str, None},
 },
 
 {
@@ -483,7 +484,7 @@ __tests__ = (
         "public_id": "soso",
         "relation_id": None,
         "service": "fanbox",
-        "updated": "2025-03-29T05:44:56.747243",
+        "updated": "iso:datetime",
     },
     "tags": [
         "うごイラ",
